Reference Files
===============

The ``wavecorr`` step uses the WAVECORR reference file, which only
applies to NIRSpec fixed-slit (FS) and MOS exposures.

.. include:: ../references_general/wavecorr_reffile.inc
